==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/SystemConnectwisehostedsetupsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemConnectwisehostedsetupsCountEndpoint import \
    SystemConnectwisehostedsetupsCountEndpoint
from pyconnectwise.endpoints.manage.SystemConnectwisehostedsetupsIdEndpoint import \
    SystemConnectwisehostedsetupsIdEndpoint
from pyconnectwise.models.manage import ConnectWiseHostedSetup
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemConnectwisehostedsetupsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "connectwisehostedsetups", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            SystemConnectwisehostedsetupsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemConnectwisehostedsetupsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemConnectwisehostedsetupsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemConnectwisehostedsetupsIdEndpoint: The initialized SystemConnectwisehostedsetupsIdEndpoint object.
        """
        child = SystemConnectwisehostedsetupsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[ConnectWiseHostedSetup]:
        """
        Performs a GET request against the /system/connectwisehostedsetups endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ConnectWiseHostedSetup]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            ConnectWiseHostedSetup,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[ConnectWiseHostedSetup]:
        """
        Performs a GET request against the /system/connectwisehostedsetups endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ConnectWiseHostedSetup]: The parsed response data.
        """
        return self._parse_many(ConnectWiseHostedSetup, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ConnectWiseHostedSetup:
        """
        Performs a POST request against the /system/connectwisehostedsetups endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ConnectWiseHostedSetup: The parsed response data.
        """
        return self._parse_one(ConnectWiseHostedSetup, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/SystemConnectwisehostedsetupsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemConnectwisehostedsetupsCountEndpoint import \
    SystemConnectwisehostedsetupsCountEndpoint
from pyconnectwise.endpoints.manage.SystemConnectwisehostedsetupsIdEndpoint import \
    SystemConnectwisehostedsetupsIdEndpoint
from pyconnectwise.models.manage import ConnectWiseHostedSetup
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemConnectwisehostedsetupsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "connectwisehostedsetups", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            SystemConnectwisehostedsetupsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemConnectwisehostedsetupsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemConnectwisehostedsetupsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemConnectwisehostedsetupsIdEndpoint: The initialized SystemConnectwisehostedsetupsIdEndpoint object.
        """
        child = SystemConnectwisehostedsetupsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[ConnectWiseHostedSetup]:
        """
        Performs a GET request against the /system/connectwisehostedsetups endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ConnectWiseHostedSetup]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), ConnectWiseHostedSetup, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[ConnectWiseHostedSetup]:
        """
        Performs a GET request against the /system/connectwisehostedsetups endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ConnectWiseHostedSetup]: The parsed response data.
        """
        return self._parse_many(ConnectWiseHostedSetup, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ConnectWiseHostedSetup:
        """
        Performs a POST request against the /system/connectwisehostedsetups endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ConnectWiseHostedSetup: The parsed response data.
        """
        return self._parse_one(ConnectWiseHostedSetup, super()._make_request("POST", data=data, params=params).json())
